import * as Knex from 'knex';
import { TableOptions } from './migrations';
interface JobOptions {
    deleteOnAcknowledged?: boolean;
    everySecs?: number;
}
/**
 * Represents a single or recurring job by ID.
 * @property {number} id Job ID number
 * @property {object} data Job data
 * @param {number} id ID number of job
 * @param {Knex} knex Knex instance to use
 * @param {TableOptions} tableOptions Table options including names
 * @param {number} pollMs Poll interval
 * @param {Knex.Transaction} tx Transaction if applicable (inside processing function)
 */
export declare class Job {
    id: number;
    private knex;
    private tx?;
    private tableOptions;
    private pollMs;
    data: any;
    /**
     * Please use Queue.getJob(jobID) to get a job. This constructor is
     * for internal use only.
     */
    constructor(id: number, knex: Knex, tableOptions: TableOptions, pollMs: number, tx?: Knex.Transaction);
    /**
     * Waits for a job to complete (only applicable to non-recurring jobs)
     */
    done(): Promise<any>;
    /**
     * Removes job from queue
     */
    remove(): Promise<void>;
}
export interface QueueOptions extends TableOptions {
    pollInterval: number;
}
/**
 * This represents a single queue.
 * @param {object} data Job data
 * @param {TableOptions} options Job options
 */
export declare class Queue {
    private name;
    private knex;
    private tableOptions;
    private pollInterval;
    private shouldProcess;
    constructor(name: string, knex: Knex, options?: Partial<QueueOptions>);
    /**
     * Adds a single or recurring job to the queue
     * @param {object} data Job data to be passed to the processing function
     * @param {JobOptions} options Job options for configuring repeat and output handling
     * @returns {Job} Created job
     */
    add(data: any, options?: JobOptions): Promise<Job>;
    /**
     * Gets a Job object from the queue.
     * @param {number} id Job ID number
     * @returns {Job} Job retrieved
     */
    getJob(id: number): Job;
    /**
     * Process runs the queue and processes jobs.
     * @param {Function} cb Callback to handle a job. Return value should be job result.
     */
    process(cb: (j: Job) => Promise<any>): void;
    shutdown(): void;
}
export {};
